@@ -13,7 +13,7 @@ describe 'oslo::db' do
         is_expected.to contain_keystone_config('database/connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/slave_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/mysql_sql_mode').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('database/idle_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/min_pool_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/max_pool_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('database/max_retries').with_value('<SERVICE DEFAULT>')
@@ -34,25 +34,25 @@ describe 'oslo::db' do
     context 'with overridden parameters' do
       let :params do
         {
-          :config_group          => 'custom_group',
-          :backend               => 'sqlalchemy',
-          :connection            => 'mysql+pymysql://db:db@localhost/db',
-          :mysql_sql_mode        => 'TRADITIONAL',
-          :idle_timeout          => '3601',
-          :min_pool_size         => '2',
-          :max_pool_size         => '100',
-          :max_retries           => '10',
-          :retry_interval        => '10',
-          :max_overflow          => '50',
-          :connection_debug      => '0',
-          :connection_trace      => true,
-          :pool_timeout          => '10',
-          :use_db_reconnect      => true,
-          :db_retry_interval     => '1',
-          :db_inc_retry_interval => true,
-          :db_max_retry_interval => '10',
-          :db_max_retries        => '20',
-          :use_tpool             => true,
+          :config_group            => 'custom_group',
+          :backend                 => 'sqlalchemy',
+          :connection              => 'mysql+pymysql://db:db@localhost/db',
+          :mysql_sql_mode          => 'TRADITIONAL',
+          :connection_recycle_time => '3601',
+          :min_pool_size           => '2',
+          :max_pool_size           => '100',
+          :max_retries             => '10',
+          :retry_interval          => '10',
+          :max_overflow            => '50',
+          :connection_debug        => '0',
+          :connection_trace        => true,
+          :pool_timeout            => '10',
+          :use_db_reconnect        => true,
+          :db_retry_interval       => '1',
+          :db_inc_retry_interval   => true,
+          :db_max_retry_interval   => '10',
+          :db_max_retries          => '20',
+          :use_tpool               => true,
         }
       end
 
@@ -60,7 +60,7 @@ describe 'oslo::db' do
         is_expected.to contain_keystone_config('custom_group/backend').with_value('sqlalchemy')
         is_expected.to contain_keystone_config('custom_group/connection').with_value('mysql+pymysql://db:db@localhost/db').with_secret(true)
         is_expected.to contain_keystone_config('custom_group/mysql_sql_mode').with_value('TRADITIONAL')
-        is_expected.to contain_keystone_config('custom_group/idle_timeout').with_value('3601')
+        is_expected.to contain_keystone_config('custom_group/connection_recycle_time').with_value('3601')
         is_expected.to contain_keystone_config('custom_group/min_pool_size').with_value('2')
         is_expected.to contain_keystone_config('custom_group/max_pool_size').with_value('100')
         is_expected.to contain_keystone_config('custom_group/max_retries').with_value('10')
